# Monolayer BN - MF/WFN

In this directory we perform a non-self-consistent (NSCF) mean-field
calculation to generate all of the Bloch states needed for the subsequent
GW/GW-BSE calculations.  The resulting wavefunction file will then be read as
`WFN` by the Epsilon code, `WFN_inner` by the Sigma code, and `WFN_co` by
Kernel and Absorption.

Follow the following steps:

1. Take a look at the input file (`kgrid.inp`) for `kgrid.x`, the executable
   that generates our k-grids for NSCF calculations.

   - How is k-space sampling in the 2D case different from the 3D case?
   - Check and make sure that the FFT grid reported in `kgrid.inp` is the same
     as the FFT grid for the SCF calculation. You can do this using the command
     `grep 'FFT dimensions' ../1-scf/out`.

2. Run `./01-get_kgrid.sh` to generate the k-grid. Take a look at the output
   output `kgrid.out` and the log `kgrid.log`.

3. Copy the k-points in the reduced BZ from `kgrid.out` and put them in the
   Quantum ESPRESSO input file (`in`) in the specified location at the end of
   the file.

4. Run `./02-calculate_wfn.run` to calculate the wavefunctions using Quantum
   ESPRESSO. This should take about 1 minute. These wavefunctions will be
   written to files in Quantum ESPRESSO format, so they will need to be
   converted to BGW format in the next step using the utility `pw2bgw.x`.

   - Check the input file `in`. How many bands are we calculating?

5. Take a look at the input file (`pp_in`) for `pw2bgw.x`, our utility that
   converts wavefunctions in Quantum ESPRESSO format to BGW format. Compare
   this input file with the documentation available in the code. 

   - Should you be writing a real or complex wavefunction? Why? What's the name
     of the wavefunction file that is output by `pw2bgw.x`?
   - This will also output a `vxc.dat` file containing the DFT approximation to
     the exchange correlation. This file will be used by Sigma. Do you know why
     this file is necessary?
   - `pw2bgw.x` will also output `RHO`, the charge density, which is required
     to run `Sigma`.

6. Run `./03-convert_wfn.run` to convert the wavefunction file from Quantum
   ESPRESSO to the BerkeleyGW format.
