## Hands-on Session: Monolayer Hexagonal-Boron Nitride

- Original author: Diana Y. Qiu


Overview
--------

In this session we will calculate the inverse dielectric matrix, quasiparticle band structure,
optical spectrum, and exciton wave functions of a monolayer of BN using the GW-BSE method.


Goals
-----

The basic goals are the following:

  1. Run a basic GW-BSE calculation for a 2D semiconductor
  2. Understand the effect of Coulomb truncation on the inverse dielectric matrix
  3. Understand the meaning of the head of the dielectric matrix in 2D
  4. Demonstrate how to calculate absorption spectra and excitonic wave functions for a 
     2D semiconductor

The stretch goals are to nonuniform k-point sampling schemes to improve convergence
with respect to k-point sampling for a 2D material. Please complete all basic goals
before moving on to stretch goals. Note, due to the time constraints of this course
the parameters are such that CSI and NNS do not make a big difference for this 
particular example. However, since these two subsampling schemes are more labor 
intensive, this tutorial acts as a guide for the workflow in future cases when
you might be working on systems (e.g. TMDs) that need such schemes to converge.

  1. Use Nonuniform Neck Subsampling (NNS) to improve k-point convergence for a GW
     calculation.
  2. Use Clustered Sampling Interpolation (CSI) to improve k-point convergence for
     a BSE calculation.
  3. Additional NNS steps are contained in the directories: 1-mf/2.4-wfnq_nns,
     2-bgw/1.2-epsilon_nns, 2-bgw/2.3-sigma_nns. Please do not complete these
     steps until you have completed the absorption calculation without subsampling.
  4. Additional CSI steps are contained in the directories: 1-mf/2.5-wfn_csi,
     2-bgw/1.3-epsilon_csi, 2-bgw/3.1-kernel_csi, 2-bgw/4.1-absorption_csi. 
     Please do not complete these steps until you have completed the absorption 
     calculation without subsampling.

In the future, if you would like to use NNS and CSI for 2D materials, please cite:

F.H. da Jornada*, D.Y. Qiu*, S.G. Louie, "Nonuniform sampling schemes of the Brillouin zone for 
many-electron perturbation-theory calculations in reduced dimensionality," Phys. Rev. B 95, 035109
(2017).

Instructions
-----------

1. Go to the ``1-mf/`` directory, where we perform all the mean-field
   calculations. Follow the steps in the README file to generate the various
   wavefunctions.

2. Go to the ``2-bgw/`` directory, where we perform GW/GW-BSE calculations.
   Follow the instructions in the README file to perform the GW/GW-BSE
   calculations.
